﻿using AutoMapper;
using BlankApp1.Common;
using BlankApp1.Common.AutoMapper;
using BlankApp1.Common.Extension;
using BlankApp1.ViewModels;
using BlankApp1.Views;
using DryIoc;

using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Logging;
using NLog.Extensions.Logging;
using PLCTool.ViewModels.BasicConfigViewModel;
using PLCTool.ViewModels.BusinessManageViewModel;
using PLCTool.ViewModels.MonitorManageViewModel;
using PLCTool.Views;
using PLCTool.Views.BasicConfigView;
using PLCTool.Views.MonitorManageView;
using Prism.DryIoc;
using Prism.Ioc;
using Prism.Services.Dialogs;
using SqlSugar;

using System.Configuration;
using System.Data;
using System.IO;
using System.Reflection;
using System.Windows;

namespace BlankApp1
{
    /// <summary>
    /// Interaction logic for App.xaml
    /// </summary>
    public partial class App 
    {
        string comConfig = ConfigurationManager.AppSettings["MySql"];
        protected override Window CreateShell()
        {
            return Container.Resolve<MainWindow>();
        }

        protected override void RegisterTypes(IContainerRegistry containerRegistry)
        {
            var factory = new NLogLoggerFactory();
            ILogger  _logger = factory.CreateLogger("NLog.config");
            containerRegistry.RegisterInstance<ILogger>(_logger);
            containerRegistry.AddRegisterExtension(Assembly.LoadFrom("BizService.dll"), Assembly.LoadFrom("BizService.dll"));//批量注入仓储
            //containerRegistry.Register<IProductRepository, ProductRepository>();
            //containerRegistry.Register<IProductService, ProductService>();
            //注册AutoMapper
            containerRegistry.RegisterSingleton<IAutoMapperProvider, AutoMapperProvider>();
            containerRegistry.Register(typeof(IMapper), GetMapper);
            containerRegistry.RegisterForNavigation<BaseConfigView, BaseConfigViewModel>();
            containerRegistry.RegisterForNavigation<TestTwoView, TestTwoViewModel>();
            containerRegistry.RegisterForNavigation<QueryView, QueryViewModel>();
            containerRegistry.RegisterForNavigation<TreeMenuView, TreeMenuViewModel>();
            containerRegistry.RegisterForNavigation<StatisticsView, StatisticsViewModel>();
            containerRegistry.RegisterForNavigation<LogView, LogViewModel>();
            containerRegistry.RegisterForNavigation<PLCPointView, PLCPointViewModel>();
            containerRegistry.RegisterForNavigation<PLCReadView, PLCReadViewModel>();
            containerRegistry.RegisterForNavigation<PLCWriteView, PLCWriteViewModel>();
            containerRegistry.RegisterDialog<PopView, PopViewModel>();
          
            containerRegistry.RegisterDialog<AddPlanView, AddPlanViewModel>();
            containerRegistry.RegisterDialog<AddDetailView, AddDetailViewModel>();
            
        }

        private IMapper GetMapper(IContainerProvider container)
        {
            var provider = container.Resolve<IAutoMapperProvider>();
            return provider.GetMapper();
        }
        protected override void OnInitialized()
        {
  
                //调试发现service为MainViewModel
                var service = App.Current.MainWindow.DataContext as IConfigureService;
                if (service != null)
                    service.Configure();
                base.OnInitialized();
          
        }

    }
}
