﻿using AutoMapper;
using BizService;

using Microsoft.Extensions.Logging;
using MiniExcelLibs;
using Model;
using Model.Dto;
using Model.Entities;
using Prism.Commands;
using Prism.Mvvm;
using Prism.Regions;
using Prism.Services.Dialogs;

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;


namespace PLCTool.ViewModels.BasicConfigViewModel
{
    public class BaseConfigViewModel : BindableBase
    {
        private readonly IDialogService _dialog;
        private readonly IOptionConfigService _optionConfigService;
        private readonly IBasicPlcTestSchemeService _basicPlcTestSchemeService;
        private readonly IBasicPlcTestSchemeDtlService _basicPlcTestSchemeDtlService;
        private readonly ILogger _logger;
        private readonly IMapper _mapper;
        private readonly IMenuService _menuService;
        public BaseConfigViewModel(IDialogService dialog, IMenuService menuService, IOptionConfigService optionConfigService, IBasicPlcTestSchemeService basicPlcTestSchemeService, IBasicPlcTestSchemeDtlService basicPlcTestSchemeDtlService ,IMapper mapper, ILogger logger)
        {
            _dialog = dialog;
            _optionConfigService = optionConfigService;
            _basicPlcTestSchemeService = basicPlcTestSchemeService;
            _basicPlcTestSchemeDtlService = basicPlcTestSchemeDtlService;
            _logger = logger;
            _mapper = mapper;
            _menuService = menuService;
           
            ExportCommand = new DelegateCommand<string>(Export);
            AddPlanCommand = new DelegateCommand<string>(AddPlan);
            EditCommand = new DelegateCommand<object>(Edit);
            DeleteCommand = new DelegateCommand<object>(Delete);
            GetConfigOption();
            GetContent();
        }

        /// <summary>
        /// 获取配置
        /// </summary>
        private void GetConfigOption()
        {
            var configList = _optionConfigService.QueryList();
            var _optionConfigs = _mapper.Map<List<OptionConfig>, List<OptionConfigDto>>(configList);
            var tests = _optionConfigs.FindAll(x => x.TypeID == 1);
            TestKinds = new List<string>();
            foreach (var test in tests)
            {
                TestKinds.Add(test.ContentOption);
            }
        }
        /// <summary>
        /// 编辑
        /// </summary>
        /// <param name="obj"></param>
         private void Edit(object obj)
        {
            //测试方案明细主键ID
            long id = Convert.ToInt64(obj);
            DialogParameters parm = new DialogParameters();
            parm.Add("Key", id);
            //弹出详情对话框
            _dialog.ShowDialog("AddPlanView",parm, async callback =>
            {
                if (callback.Result == ButtonResult.OK)
                {
                    //更新表格，重新获取
                    GetContent();
                }

            });
        }
        /// <summary>
        /// 删除操作
        /// </summary>
        /// <param name="obj"></param>
        private void Delete(object obj)
        {
            int id = Convert.ToInt32(obj);
            MessageBoxResult boxResult = MessageBox.Show("确认删除此条数据?", "确认", MessageBoxButton.OKCancel, MessageBoxImage.Question);
            if (boxResult == MessageBoxResult.OK)
            {
                
                _basicPlcTestSchemeDtlService.Delete(id);
                //更新表格，重新获取
                GetContent();
            }
        }

        private void AddPlan(string obj)
        {

            //弹出详情对话框
            _dialog.ShowDialog("AddPlanView", async callback =>
            {
                if (callback.Result == ButtonResult.OK)
                {
                    //更新表格，重新获取
                    GetContent();
                }

            });
        }

        private void Export(object obj)
        {


            using (System.Windows.Forms.SaveFileDialog saveFileDialog = new System.Windows.Forms.SaveFileDialog()
            {
                //设置文件类型
                //书写规则例如：txt files(*.txt)|*.txt
                Filter = "Excel files(*.xlsx)|*.xlsx|All files(*.*)|*.*",
                //设置默认文件名（可以不设置）
                FileName = "配置导出",

                //获取或设置一个值，该值指示如果用户省略扩展名，文件对话框是否自动在文件名中添加扩展名。（可以不设置）
                AddExtension = true,

                //保存对话框是否记忆上次打开的目录
                RestoreDirectory = true
            })
            {
                // Show save file dialog box

                //点了保存按钮进入
                if (saveFileDialog.ShowDialog() == System.Windows.Forms.DialogResult.OK)
                {
                    try
                    {
                        //获得文件路径
                        string localFilePath = saveFileDialog.FileName.ToString();

                        //string filePathWithName = localFilePath + ".xlsx";

                        //获取文件内容
                        MiniExcel.SaveAs(localFilePath, BaseConfigList);
                    }
                    catch (Exception ex)
                    {

                    }


                }

            }
        }
        /// <summary>
        /// 获取解决方案
        /// </summary>
        private void GetContent()
        {
            //所有测试方案
            var schlist = _basicPlcTestSchemeService.QueryList();
            var configList = _mapper.Map<List<bas_plc_test_scheme>, List<BasicPlcTestSchemeDto>>(schlist);
            //清空集合
            BaseConfigList.Clear();
            //查找测试项名称
            foreach (var sch in configList)
            {
                long schId = sch.SchemeId;
                //在解决方案详细表中查找所有的测试项
                var items=_basicPlcTestSchemeDtlService.FindAllBySchId(schId);
                foreach(var item in items)
                {
                    BasicPlcTestSchemeDto basicPlcTestSchemeDto = new BasicPlcTestSchemeDto();
                    basicPlcTestSchemeDto.SchemeId = item.scheme_dtl_id;
                    basicPlcTestSchemeDto.SchemeName= sch.SchemeName;
                    basicPlcTestSchemeDto.DeviceName= sch.DeviceName;
                    switch(item.item_type)
                    {
                        case 0:
                            basicPlcTestSchemeDto.ItemType = "前置项";
                            break;
                        case 1:
                            basicPlcTestSchemeDto.ItemType = "PLC点位测试项";
                            break; 
                        case 2:
                            basicPlcTestSchemeDto.ItemType = "Robot动作测试";
                            break;
                    }
               
                    basicPlcTestSchemeDto.ItemName=item.item_name;
                    basicPlcTestSchemeDto.CreateBy=sch.CreateBy;
                    basicPlcTestSchemeDto.CreateTime = sch.CreateTime;
                    BaseConfigList.Add(basicPlcTestSchemeDto);
                }

            }
          
        }

        private void PopMethod(string obj)
        {
            DialogParameters parm = new DialogParameters();
            parm.Add("Key", MyContent);
            //弹出详情对话框
            _dialog.ShowDialog("PopView", parm, async callback =>
            {
                if (callback.Result == ButtonResult.OK)
                {
                    MyContent = callback.Parameters.GetValue<string>("ReturnValue");
                }

            });
        }
        #region 命令绑定
        public DelegateCommand<string> AddPlanCommand { set; get; }
        public DelegateCommand<object> EditCommand { set; get; }

        public DelegateCommand<object> DeleteCommand { set; get; }
        public DelegateCommand<string> ExportCommand { set; get; }
        #endregion
        #region 数据绑定

        /// <summary>
        /// 测试项
        /// </summary>
        private List<string> testKinds = new List<string>();
        public List<string> TestKinds
        {
            get { return testKinds; }
            set { testKinds = value; RaisePropertyChanged(); }
        }
        /// <summary>
        /// 
        /// </summary>
        private string selectTest;
        public string SelectTest
        {
            get { return selectTest; }
            set { selectTest = value; RaisePropertyChanged(); }
        }

        private string myContent = string.Empty;
        public string MyContent
        {
            get { return myContent; }
            set { SetProperty(ref myContent, value); }
        }

        private ObservableCollection<BasicPlcTestSchemeDto> baseConfigList = new ObservableCollection<BasicPlcTestSchemeDto>();
        public ObservableCollection<BasicPlcTestSchemeDto> BaseConfigList
        {
            get { return baseConfigList; }
            set { SetProperty(ref baseConfigList, value); }
        }

        #endregion

    }
}
